@@ -139,8 +139,8 @@ def export(quotes, saveFile, enc):
 			save.write(quotes[i][1:-1])
 			save.append("\n")
 		else:
-			save.append(quotes[i][1:-1],newline=True)
-			# save.append("\n")
+			save.append(quotes[i][1:-1],newline=False)
+			save.append("\n")
 
 
 
